@@ -6,7 +6,7 @@ SL.glmnet <- function(Y, X, newX, family, obsWeights, id, alpha = 1, nfolds = 10
     newX <- model.matrix(~ -1 + ., newX)
   }
   # now use CV to find lambda
-  fitCV <- cv.glmnet(x = X, y = Y, weights = obsWeights, lambda = NULL, type.measure = 'deviance', nfolds = nfolds, family = family$family, alpha = alpha, nlambda = nlambda)
+  fitCV <- glmnet::cv.glmnet(x = X, y = Y, weights = obsWeights, lambda = NULL, type.measure = 'deviance', nfolds = nfolds, family = family$family, alpha = alpha, nlambda = nlambda)
   # two options for lambda, fitCV$lambda.min and fitCV$lambda.1se
   pred <- predict(fitCV$glmnet.fit, newx = newX, s = ifelse(useMin, fitCV$lambda.min, fitCV$lambda.1se), type = 'response')
   fit <- list(object = fitCV, useMin = useMin)
