@@ -3,12 +3,12 @@
 SL.randomForest <- function(Y, X, newX, family, mtry = ifelse(family$family=="gaussian", floor(sqrt(ncol(X))), max(floor(ncol(X)/3), 1)), ntree=1000, nodesize = ifelse(family$family=="gaussian", 5, 1), ...) {
 	.SL.require('randomForest')
 	if(family$family=="gaussian"){
-		fit.rf <- randomForest(Y ~ ., data = X, ntree = ntree, xtest = newX, keep.forest = TRUE, mtry = mtry, nodesize = nodesize)
+		fit.rf <- randomForest::randomForest(Y ~ ., data = X, ntree = ntree, xtest = newX, keep.forest = TRUE, mtry = mtry, nodesize = nodesize)
 		pred <- fit.rf$test$predicted
 		fit <- list(object = fit.rf)
 	}
 	if(family$family=="binomial"){
-		fit.rf <- randomForest(y = as.factor(Y), x = X, ntree = ntree, xtest = newX, keep.forest = TRUE, mtry = mtry, nodesize = nodesize)
+		fit.rf <- randomForest::randomForest(y = as.factor(Y), x = X, ntree = ntree, xtest = newX, keep.forest = TRUE, mtry = mtry, nodesize = nodesize)
 		pred <- fit.rf$test$votes[, 2]
 		fit <- list(object = fit.rf)
 	}
